@@ -2,7 +2,7 @@ package Finance::Nadex;
 
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use LWP::UserAgent;
 use JSON;
@@ -11,23 +11,15 @@ use Finance::Nadex::Order;
 use Finance::Nadex::Position;
 use Finance::Nadex::Contract;
 
-use constant LOGIN_URL =>
-  'https://trade.nadex.com/iDeal/v2/security/authenticate';
-use constant SEND_ORDER_URL =>
-  'https://trade.nadex.com/iDeal/dma/workingorders';
-use constant RETRIEVE_ORDERS_URL =>
-  'https://trade.nadex.com/iDeal/orders/workingorders';
-use constant RETRIEVE_ORDER_URL =>
-  'https://trade.nadex.com/iDeal/markets/details/workingorders';
-use constant CANCEL_ORDER_URL =>
-  'https://trade.nadex.com/iDeal/orders/workingorders/dma';
-use constant RETRIEVE_POSITIONS_URL =>
-  'https://trade.nadex.com/iDeal/orders/positions';
-use constant RETRIEVE_POSITION_URL =>
-  'https://trade.nadex.com/iDeal/markets/details/position';
-use constant EPIC_URL => 'https://trade.nadex.com/iDeal/markets/details';
-use constant MARKET_LIST_URL =>
-  'https://trade.nadex.com/iDeal/markets/navigation';
+use constant LOGIN_URL              => '/iDeal/v2/security/authenticate';
+use constant SEND_ORDER_URL         => '/iDeal/dma/workingorders';
+use constant RETRIEVE_ORDERS_URL    => '/iDeal/orders/workingorders';
+use constant RETRIEVE_ORDER_URL     => '/iDeal/markets/details/workingorders';
+use constant CANCEL_ORDER_URL       => '/iDeal/orders/workingorders/dma';
+use constant RETRIEVE_POSITIONS_URL => '/iDeal/orders/positions';
+use constant RETRIEVE_POSITION_URL  => '/iDeal/markets/details/position';
+use constant EPIC_URL               => '/iDeal/markets/details';
+use constant MARKET_LIST_URL        => '/iDeal/markets/navigation';
 
 my $session_id;
 
@@ -85,7 +77,7 @@ sub cancel_order {
 
     my $deal_id = $args{id};
 
-    my $cancel_order_url = CANCEL_ORDER_URL . '/' . $deal_id;
+    my $cancel_order_url = $self->{base_url}.CANCEL_ORDER_URL . '/' . $deal_id;
 
     my $cancel_time    = time;
     my $cancel_content = qq~
@@ -170,7 +162,7 @@ sub create_order {
 
     }~;
 
-    my $order = $self->_post( SEND_ORDER_URL, $order_content );
+    my $order = $self->_post( $self->{base_url}.SEND_ORDER_URL, $order_content );
 
     my $deal_reference_id = $order->{dealReference} if defined $order;
 
@@ -192,7 +184,7 @@ sub get_contract {
 "ERROR: Finance::Nadex::get_contract(): specified 'epic' (->$args{epic}<-) is not valid\n"
       unless $args{epic};
 
-    my $epic_url = EPIC_URL . '/' . $args{epic};
+    my $epic_url = $self->{base_url}.EPIC_URL . '/' . $args{epic};
     my $epic_ref = $self->_get($epic_url);
 
     return unless $epic_ref;
@@ -249,7 +241,7 @@ sub get_contracts {
     $args{instrument} = $index_name{ $args{instrument} }
       if exists $index_name{ $args{instrument} };
 
-    my $market_list_ref = $self->_get(MARKET_LIST_URL);
+    my $market_list_ref = $self->_get($self->{base_url}.MARKET_LIST_URL);
 
     die
 "ERROR: Finance::Nadex::get_contracts(): failed to retrieve the market list from the exchange\n"
@@ -263,7 +255,7 @@ sub get_contracts {
     return unless $market_id;
 
     my $instruments_list_ref =
-      $self->_get( MARKET_LIST_URL . '/' . $market_id );
+      $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $market_id );
 
     die
 "ERROR: Finance::Nadex::get_contracts(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -278,7 +270,7 @@ sub get_contracts {
     return unless $instrument_id;
 
     my $instrument_list_ref =
-      $self->_get( MARKET_LIST_URL . '/' . $instrument_id );
+      $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $instrument_id );
 
     die
 "ERROR: Finance::Nadex::get_contracts(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -293,7 +285,7 @@ sub get_contracts {
 
     my @contracts;
     my $series_list_ref =
-      $self->_get( MARKET_LIST_URL . '/' . $time_series_id );
+      $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $time_series_id );
 
     die
 "ERROR: Finance::Nadex::get_contracts(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -352,7 +344,7 @@ sub get_epic {
 
     $args{time} = lc( $args{time} ) if exists $args{time};
 
-    my $market_list_ref = $self->_get(MARKET_LIST_URL);
+    my $market_list_ref = $self->_get($self->{base_url}.MARKET_LIST_URL);
 
     die
 "ERROR: Finance::Nadex::get_epic(): failed to retrieve the market list from the exchange\n"
@@ -365,7 +357,7 @@ sub get_epic {
 
     return undef unless $market_id;
 
-    $market_list_ref = $self->_get( MARKET_LIST_URL . "/$market_id" );
+    $market_list_ref = $self->_get( $self->{base_url}.MARKET_LIST_URL . "/$market_id" );
 
     die
 "ERROR: Finance::Nadex::get_epic(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -378,7 +370,7 @@ sub get_epic {
 
     return undef unless $market_id;
 
-    $market_list_ref = $self->_get( MARKET_LIST_URL . "/$market_id" );
+    $market_list_ref = $self->_get( $self->{base_url}.MARKET_LIST_URL . "/$market_id" );
 
     die
 "ERROR: Finance::Nadex::get_epic(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -404,7 +396,7 @@ sub get_epic {
 
     return undef unless $market_id;
 
-    $market_list_ref = $self->_get( MARKET_LIST_URL . "/$market_id" );
+    $market_list_ref = $self->_get( $self->{base_url}.MARKET_LIST_URL . "/$market_id" );
 
     die
 "ERROR: Finance::Nadex::get_epic(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -440,7 +432,7 @@ sub get_market_instruments {
       "ERROR: Finance::Nadex::get_market_instruments(): invalid market name\n"
       unless $args{name};
 
-    my $market_list_ref = $self->_get(MARKET_LIST_URL);
+    my $market_list_ref = $self->_get($self->{base_url}.MARKET_LIST_URL);
 
     die
 "ERROR: Finance::Nadex::get_market_instruments(): failed to retrieve the market list from the exchange\n"
@@ -453,7 +445,7 @@ sub get_market_instruments {
 
     return unless $market_id;
 
-    $market_list_ref = $self->_get( MARKET_LIST_URL . '/' . $market_id );
+    $market_list_ref = $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $market_id );
 
     die
 "ERROR: Finance::Nadex::get_market_instruments(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -473,7 +465,7 @@ sub get_markets {
     croak "ERROR: Finance::Nadex::get_markets(): must be logged in\n"
       unless $self->logged_in;
 
-    my $market_list_ref = $self->_get(MARKET_LIST_URL);
+    my $market_list_ref = $self->_get($self->{base_url}.MARKET_LIST_URL);
 
     die
 "ERROR: Finance::Nadex::get_markets(): failed to retrieve the market list from the exchange\n"
@@ -518,7 +510,7 @@ sub get_quote {
                     instrument => $instrument,
                     series     => $series
                 );
-                my $epic_url = EPIC_URL . '/' . $contract->epic;
+                my $epic_url = $self->{base_url}.EPIC_URL . '/' . $contract->epic;
                 my $epic_ref = $self->_get($epic_url);
 
                 return undef unless $epic_ref;
@@ -551,7 +543,7 @@ sub get_time_series {
 "ERROR: Finance::Nadex::get_time_series(): must specify a named argument 'instrument'\n"
       unless exists $args{instrument};
 
-    my $market_list_ref = $self->_get(MARKET_LIST_URL);
+    my $market_list_ref = $self->_get($self->{base_url}.MARKET_LIST_URL);
 
     die
 "ERROR: Finance::Nadex::get_time_series(): failed to retrieve the market list from the exchange\n"
@@ -565,7 +557,7 @@ sub get_time_series {
     return unless $market_id;
 
     my $instruments_list_ref =
-      $self->_get( MARKET_LIST_URL . '/' . $market_id );
+      $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $market_id );
 
     die
 "ERROR: Finance::Nadex::get_time_series(): failed to retrieve the market list from the exchange for market $market_id\n"
@@ -586,7 +578,7 @@ sub get_time_series {
     return unless $instrument_id;
 
     my $instrument_list_ref =
-      $self->_get( MARKET_LIST_URL . '/' . $instrument_id );
+      $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $instrument_id );
 
     die
 "ERROR: Finance::Nadex::get_time_series(): failed to retrieve the market list from the exchange for market $instrument_id\n"
@@ -604,7 +596,7 @@ sub get_time_series {
         return unless $instrument_id;
 
         $instrument_list_ref =
-          $self->_get( MARKET_LIST_URL . '/' . $instrument_id );
+          $self->_get( $self->{base_url}.MARKET_LIST_URL . '/' . $instrument_id );
 
         die
 "ERROR: Finance::Nadex::get_time_series(): failed to retrieve the market list from the exchange for market $instrument_id\n"
@@ -654,7 +646,7 @@ sub login {
     $self->{username} = $args{username} if exists $args{username};
     $self->{password} = $args{password} if exists $args{password};
 
-    my $login_url = LOGIN_URL;
+    my $login_url = $self->{base_url}.LOGIN_URL;
 
     my $login_content = qq~
      { 
@@ -680,9 +672,15 @@ sub new {
     my $class = shift;
     my %args  = @_;
 
+    if (exists $args{platform} && $args{platform} eq 'demo') {
+        $args{base_url} = 'https://demo-trade.nadex.com'; 
+    } else {
+        $args{base_url} = 'https://trade.nadex.com';
+    }
+
     my $ua = LWP::UserAgent->new( ssl_opts => { verify_hostname => 0 } );
 
-    push @{ $ua->requests_redirectable }, 'POST';
+    push @{ $ua->requests_redirectable }, 'POST', 'DELETE';
     $ua->agent(
 "vendor=IG Group | applicationType=dxd | platform=Android | deviceType=generic | version=1.13.2"
     );
@@ -708,7 +706,7 @@ sub retrieve_order {
 
     my $order_id = $args{id};
 
-    my $retrieve_order_url = RETRIEVE_ORDER_URL . '/' . $order_id;
+    my $retrieve_order_url = $self->{base_url}.RETRIEVE_ORDER_URL . '/' . $order_id;
 
     my $order_ref = $self->_get($retrieve_order_url);
 
@@ -725,7 +723,7 @@ sub retrieve_orders {
     croak "ERROR: Finance::Nadex::retrieve_orders(): must be logged in\n"
       unless $self->logged_in();
 
-    my $retrieve_orders_url = RETRIEVE_ORDERS_URL;
+    my $retrieve_orders_url = $self->{base_url}.RETRIEVE_ORDERS_URL;
 
     my $order_list_ref = $self->_get($retrieve_orders_url);
 
@@ -757,7 +755,7 @@ sub retrieve_position {
 
     my $position_id = $args{id};
 
-    my $retrieve_positions_url = RETRIEVE_POSITION_URL . '/' . $position_id;
+    my $retrieve_positions_url = $self->{base_url}.RETRIEVE_POSITION_URL . '/' . $position_id;
 
     my $position_ref = $self->_get($retrieve_positions_url);
 
@@ -774,7 +772,7 @@ sub retrieve_positions {
     croak "ERROR: Finance::Nadex::retrieve_positions(): must be logged in\n"
       unless $self->logged_in;
 
-    my $retrieve_positions_url = RETRIEVE_POSITIONS_URL;
+    my $retrieve_positions_url = $self->{base_url}.RETRIEVE_POSITIONS_URL;
 
     my $position_list_ref = $self->_get($retrieve_positions_url);
 
